<?xml version = "1.0" encoding = "UTF-8"?>

<!--$Revision: 1.2 $-->
<xsl:stylesheet xmlns:xsl = "http://www.w3.org/1999/XSL/Transform" 
	xmlns:xsi = "http://www.w3.org/2001/XMLSchema-instance" 
	xmlns:rim = "urn:oasis:names:tc:ebxml-regrep:rim:xsd:2.1" 
	xmlns:rs = "urn:oasis:names:tc:ebxml-regrep:registry:xsd:2.1" 
	xmlns:tp = "http://www.oasis-open.org/committees/ebxml-cppa/schema/cpp-cpa-2_0.xsd" 
	xmlns:xlink = "http://www.w3.org/1999/xlink" version = "1.0">

	<xsl:output method = "xml" indent = "yes"/>
	<xsl:strip-space elements = "*"/>
        <xsl:param name="repositoryItem"></xsl:param>

	<xsl:template match = "/">

		<!-- create the list -->  
		<rim:LeafRegistryObjectList xsi:schemaLocation = "urn:oasis:names:tc:ebxml-regrep:registry:xsd:2.1 http://www.oasis-open.org/committees/regrep/documents/2.1/schema/rs.xsd urn:oasis:names:tc:ebxml-regrep:rim:xsd:2.1 http://www.oasis-open.org/committees/regrep/documents/2.1/schema/rim.xsd">  
			<!-- process all the rim:ExtrinsicObjects -->			    
                        <!--xsl:message>
                          <xsl:value-of select="name(*[1])"/> is what we found
                        </xsl:message-->

                          <xsl:apply-templates select = "//rim:ExtrinsicObject"/>  
		</rim:LeafRegistryObjectList>


	</xsl:template>
        
	<xsl:template match = "rim:ExtrinsicObject">  
		<!-- store CPP in variable -->	  
		<xsl:variable name = "cpp" select = "document($repositoryItem, .)"/> 
     
		<!-- store PartyInfo for convenience -->	  
		<xsl:variable name = "PartyInfo" select = "$cpp/tp:CollaborationProtocolProfile/tp:PartyInfo"/>  

		<!-- another convenience... -->			    
		<xsl:variable name = "crole" select = "$PartyInfo/tp:CollaborationRole"/>    


		<!-- Make an ExtrinsicObject in the output -->		  
		<rim:ExtrinsicObject id = "{@id}" objectType = "{@objectType}">    
			<!-- The name is derived from the tp:partyName attriubute on the party? -->		    
			<rim:Name>      
				<rim:LocalizedString value = "{$PartyInfo/@tp:partyName}"/>    
			</rim:Name>

			<!-- Copy the description straight through -->			    
			<xsl:copy-of select = "rim:Description"/>

			<!-- Role Slot -->
			<Slot name = "Role">
				<ValueList>
					<Value><xsl:value-of select="$crole/tp:Role/@tp:name"/></Value>
				</ValueList>
			</Slot>

			<!--rim:Classification classifiedObject = "{@id}" classificationScheme = "idForCPPAScheme" nodeRepresentation = "{$crole/tp:Role/@tp:name}"/-->    

			<!-- Process Slot -->
			<Slot name = "ProcessSpecification">
				<ValueList>
					<Value><xsl:value-of select="$crole/tp:ProcessSpecification/@tp:name"/></Value>
				</ValueList>
			</Slot>
			<!--rim:Classification classifiedObject = "{@id}" classificationScheme = "idForProcessScheme" nodeRepresentation = "{$crole/tp:ProcessSpecification/@tp:name}"/-->    


			<!-- Get DUNS id opnly if PartyId type is DUNS -->
			<xsl:if test='$PartyInfo/tp:PartyId/@tp:type="urn:oasis:names:tc:ebxml-cppa:partyid-type:duns"'>
				<!-- DUNS identifier -->
				<rim:ExternalIdentifier identificationScheme = "urn:uuid:fc9bd8fd-73c4-4d83-8dd6-8a07eec79dda" value = "{$PartyInfo/tp:PartyId}"/> 
			</xsl:if>

		</rim:ExtrinsicObject>  

		<!-- ExternalLink for PartyRef/@xlink:href -->	  
		<rim:ExternalLink id = "partyRefId" externalURI = "{$PartyInfo/tp:PartyRef/@xlink:href}"/>						  
		<rim:Association id = "partyRefId-CPAId" associationType = "ExternallyLinks" sourceObject = "partyRefId" targetObject = "{@id}"/>    

		<!-- ExternalLink for ProcessSpecification/@xlink:href -->
		<rim:ExternalLink id = "processHRefId" externalURI = "{$crole/tp:ProcessSpecification/@xlink:href}"/>
		<rim:Association id = "processHRefId-CPAId" associationType = "ExternallyLinks" sourceObject = "processHRefId" targetObject = "{@id}"/>    

		<!--existing DUNS scheme. ObjctRef needed to satisfy validation -->
		<rim:ObjectRef id = "urn:uuid:fc9bd8fd-73c4-4d83-8dd6-8a07eec79dda"/>

		<!--existing CPPA scheme. ObjctRef needed to satisfy validation -->
		<!--rim:ObjectRef id = "idForCPPAScheme"/-->

		<!--existing ProcessSpecification@name scheme. ObjctRef needed to satisfy validation -->
		<!--rim:ObjectRef id = "idForProcessScheme"/-->
                                                

        </xsl:template>

</xsl:stylesheet>
